#include <stdio.h>
#include <stdlib.h>
#include "libimobiledevice.h"
#include "lockdown.h"
#include "plist.h"

static const char *kUserPrefKey = "com.apple.mobile.user_preferences";
static const char *kDeviceName = "DeviceName";

int main (int argc, const char * argv[]) 
{
	lockdownd_client_t client = NULL;
	lockdownd_error_t lderr = LOCKDOWN_E_UNKNOWN_ERROR;
	idevice_t device = NULL;
	idevice_error_t ret = IDEVICE_E_UNKNOWN_ERROR;
	plist_t plvalue = NULL;
	plist_t global = NULL;
	plist_t ptr = NULL;
	char *str = NULL;
	
	if (argc > 1)
	{
		ret = idevice_new(&device, argv[1]);
		
		if (ret != IDEVICE_E_SUCCESS || !device)
		{
			if (device)
				idevice_free(device);
			return 0;
		}
		
		lderr = lockdownd_client_new_with_handshake(device, &client, "Swinsian");
		if (lderr != LOCKDOWN_E_SUCCESS)
		{
			idevice_free(device);
			return 0;
		}
		
		lockdownd_get_value(client, NULL, NULL, &global);
		lockdownd_get_value(client, kUserPrefKey, NULL, &plvalue);
		
		ptr = plist_dict_get_item(global, kDeviceName);
		plist_get_string_val(ptr, &str);
		if (str)
		{
			fprintf(stdout, "%s", str);
			free(str);
		}
		if (plvalue)
			plist_free(plvalue);
		if (global)
			plist_free(global);
		
		lockdownd_client_free(client);
		idevice_free(device);
	}

    return 0;
}
